# This file has been autogenerated by the pywayland scanner

# Copyright © 2017 Drew DeVault
#
# Permission to use, copy, modify, distribute, and sell this
# software and its documentation for any purpose is hereby granted
# without fee, provided that the above copyright notice appear in
# all copies and that both that copyright notice and this permission
# notice appear in supporting documentation, and that the name of
# the copyright holders not be used in advertising or publicity
# pertaining to distribution of the software without specific,
# written prior permission.  The copyright holders make no
# representations about the suitability of this software for any
# purpose.  It is provided "as is" without express or implied
# warranty.
#
# THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
# SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
# FITNESS, IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
# SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
# AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
# ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
# THIS SOFTWARE.

from __future__ import annotations

import enum

from pywayland.protocol_core import (
    Argument,
    ArgumentType,
    Global,
    Interface,
    Proxy,
    Resource,
)

from ..wayland import WlOutput
from ..wayland import WlSurface
from .zwlr_layer_surface_v1 import ZwlrLayerSurfaceV1


class ZwlrLayerShellV1(Interface):
    """Create surfaces that are layers of the desktop

    Clients can use this interface to assign the surface_layer role to
    wl_surfaces. Such surfaces are assigned to a "layer" of the output and
    rendered with a defined z-depth respective to each other. They may also be
    anchored to the edges and corners of a screen and specify input handling
    semantics. This interface should be suitable for the implementation of many
    desktop shell components, and a broad number of other applications that
    interact with the desktop.
    """

    name = "zwlr_layer_shell_v1"
    version = 5

    class error(enum.IntEnum):
        role = 0
        invalid_layer = 1
        already_constructed = 2

    class layer(enum.IntEnum):
        background = 0
        bottom = 1
        top = 2
        overlay = 3


class ZwlrLayerShellV1Proxy(Proxy[ZwlrLayerShellV1]):
    interface = ZwlrLayerShellV1

    @ZwlrLayerShellV1.request(
        Argument(ArgumentType.NewId, interface=ZwlrLayerSurfaceV1),
        Argument(ArgumentType.Object, interface=WlSurface),
        Argument(ArgumentType.Object, interface=WlOutput, nullable=True),
        Argument(ArgumentType.Uint),
        Argument(ArgumentType.String),
    )
    def get_layer_surface(self, surface: WlSurface, output: WlOutput | None, layer: int, namespace: str) -> Proxy[ZwlrLayerSurfaceV1]:
        """Create a layer_surface from a surface

        Create a layer surface for an existing surface. This assigns the role
        of layer_surface, or raises a protocol error if another role is already
        assigned.

        Creating a layer surface from a
        :class:`~pywayland.protocol.wayland.WlSurface` which has a buffer
        attached or committed is a client error, and any attempts by a client
        to attach or manipulate a buffer prior to the first
        layer_surface.configure call must also be treated as errors.

        After creating a layer_surface object and setting it up, the client
        must perform an initial commit without any buffer attached. The
        compositor will reply with a layer_surface.configure event. The client
        must acknowledge it and is then allowed to attach a buffer to map the
        surface.

        You may pass NULL for output to allow the compositor to decide which
        output to use. Generally this will be the one that the user most
        recently interacted with.

        Clients can specify a namespace that defines the purpose of the layer
        surface.

        :param surface:
        :type surface:
            :class:`~pywayland.protocol.wayland.WlSurface`
        :param output:
        :type output:
            :class:`~pywayland.protocol.wayland.WlOutput` or `None`
        :param layer:
            layer to add this surface to
        :type layer:
            `ArgumentType.Uint`
        :param namespace:
            namespace for the layer surface
        :type namespace:
            `ArgumentType.String`
        :returns:
            :class:`~pywayland.protocol.wlr_layer_shell_unstable_v1.ZwlrLayerSurfaceV1`
        """
        id = self._marshal_constructor(0, ZwlrLayerSurfaceV1, surface, output, layer, namespace)
        return id

    @ZwlrLayerShellV1.request(version=3)
    def destroy(self) -> None:
        """Destroy the layer_shell object

        This request indicates that the client will not use the layer_shell
        object any more. Objects that have been created through this instance
        are not affected.
        """
        self._marshal(1)
        self._destroy()


class ZwlrLayerShellV1Resource(Resource):
    interface = ZwlrLayerShellV1


class ZwlrLayerShellV1Global(Global):
    interface = ZwlrLayerShellV1


ZwlrLayerShellV1._gen_c()
ZwlrLayerShellV1.proxy_class = ZwlrLayerShellV1Proxy
ZwlrLayerShellV1.resource_class = ZwlrLayerShellV1Resource
ZwlrLayerShellV1.global_class = ZwlrLayerShellV1Global
