# This file has been autogenerated by the pywayland scanner

# Copyright © 2017 Drew DeVault
#
# Permission to use, copy, modify, distribute, and sell this
# software and its documentation for any purpose is hereby granted
# without fee, provided that the above copyright notice appear in
# all copies and that both that copyright notice and this permission
# notice appear in supporting documentation, and that the name of
# the copyright holders not be used in advertising or publicity
# pertaining to distribution of the software without specific,
# written prior permission.  The copyright holders make no
# representations about the suitability of this software for any
# purpose.  It is provided "as is" without express or implied
# warranty.
#
# THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
# SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
# FITNESS, IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
# SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
# AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
# ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
# THIS SOFTWARE.

from __future__ import annotations

import enum

from pywayland.protocol_core import (
    Argument,
    ArgumentType,
    Global,
    Interface,
    Proxy,
    Resource,
)

from ..xdg_shell import XdgPopup


class ZwlrLayerSurfaceV1(Interface):
    """Layer metadata interface

    An interface that may be implemented by a
    :class:`~pywayland.protocol.wayland.WlSurface`, for surfaces that are
    designed to be rendered as a layer of a stacked desktop-like environment.

    Layer surface state (layer, size, anchor, exclusive zone, margin,
    interactivity) is double-buffered, and will be applied at the time
    :func:`WlSurface.commit() <pywayland.protocol.wayland.WlSurface.commit>` of
    the corresponding :class:`~pywayland.protocol.wayland.WlSurface` is called.

    Attaching a null buffer to a layer surface unmaps it.

    Unmapping a layer_surface means that the surface cannot be shown by the
    compositor until it is explicitly mapped again. The layer_surface returns
    to the state it had right after layer_shell.get_layer_surface. The client
    can re-map the surface by performing a commit without any buffer attached,
    waiting for a configure event and handling it as usual.
    """

    name = "zwlr_layer_surface_v1"
    version = 5

    class keyboard_interactivity(enum.IntEnum):
        none = 0
        exclusive = 1
        on_demand = 2

    class error(enum.IntEnum):
        invalid_surface_state = 0
        invalid_size = 1
        invalid_anchor = 2
        invalid_keyboard_interactivity = 3
        invalid_exclusive_edge = 4

    class anchor(enum.IntFlag):
        top = 1
        bottom = 2
        left = 4
        right = 8


class ZwlrLayerSurfaceV1Proxy(Proxy[ZwlrLayerSurfaceV1]):
    interface = ZwlrLayerSurfaceV1

    @ZwlrLayerSurfaceV1.request(
        Argument(ArgumentType.Uint),
        Argument(ArgumentType.Uint),
    )
    def set_size(self, width: int, height: int) -> None:
        """Sets the size of the surface

        Sets the size of the surface in surface-local coordinates. The
        compositor will display the surface centered with respect to its
        anchors.

        If you pass 0 for either value, the compositor will assign it and
        inform you of the assignment in the configure event. You must set your
        anchor to opposite edges in the dimensions you omit; not doing so is a
        protocol error. Both values are 0 by default.

        Size is double-buffered, see :func:`WlSurface.commit()
        <pywayland.protocol.wayland.WlSurface.commit>`.

        :param width:
        :type width:
            `ArgumentType.Uint`
        :param height:
        :type height:
            `ArgumentType.Uint`
        """
        self._marshal(0, width, height)

    @ZwlrLayerSurfaceV1.request(
        Argument(ArgumentType.Uint),
    )
    def set_anchor(self, anchor: int) -> None:
        """Configures the anchor point of the surface

        Requests that the compositor anchor the surface to the specified edges
        and corners. If two orthogonal edges are specified (e.g. 'top' and
        'left'), then the anchor point will be the intersection of the edges
        (e.g. the top left corner of the output); otherwise the anchor point
        will be centered on that edge, or in the center if none is specified.

        Anchor is double-buffered, see :func:`WlSurface.commit()
        <pywayland.protocol.wayland.WlSurface.commit>`.

        :param anchor:
        :type anchor:
            `ArgumentType.Uint`
        """
        self._marshal(1, anchor)

    @ZwlrLayerSurfaceV1.request(
        Argument(ArgumentType.Int),
    )
    def set_exclusive_zone(self, zone: int) -> None:
        """Configures the exclusive geometry of this surface

        Requests that the compositor avoids occluding an area with other
        surfaces. The compositor's use of this information is implementation-
        dependent - do not assume that this region will not actually be
        occluded.

        A positive value is only meaningful if the surface is anchored to one
        edge or an edge and both perpendicular edges. If the surface is not
        anchored, anchored to only two perpendicular edges (a corner), anchored
        to only two parallel edges or anchored to all edges, a positive value
        will be treated the same as zero.

        A positive zone is the distance from the edge in surface-local
        coordinates to consider exclusive.

        Surfaces that do not wish to have an exclusive zone may instead specify
        how they should interact with surfaces that do. If set to zero, the
        surface indicates that it would like to be moved to avoid occluding
        surfaces with a positive exclusive zone. If set to -1, the surface
        indicates that it would not like to be moved to accommodate for other
        surfaces, and the compositor should extend it all the way to the edges
        it is anchored to.

        For example, a panel might set its exclusive zone to 10, so that
        maximized shell surfaces are not shown on top of it. A notification
        might set its exclusive zone to 0, so that it is moved to avoid
        occluding the panel, but shell surfaces are shown underneath it. A
        wallpaper or lock screen might set their exclusive zone to -1, so that
        they stretch below or over the panel.

        The default value is 0.

        Exclusive zone is double-buffered, see :func:`WlSurface.commit()
        <pywayland.protocol.wayland.WlSurface.commit>`.

        :param zone:
        :type zone:
            `ArgumentType.Int`
        """
        self._marshal(2, zone)

    @ZwlrLayerSurfaceV1.request(
        Argument(ArgumentType.Int),
        Argument(ArgumentType.Int),
        Argument(ArgumentType.Int),
        Argument(ArgumentType.Int),
    )
    def set_margin(self, top: int, right: int, bottom: int, left: int) -> None:
        """Sets a margin from the anchor point

        Requests that the surface be placed some distance away from the anchor
        point on the output, in surface-local coordinates. Setting this value
        for edges you are not anchored to has no effect.

        The exclusive zone includes the margin.

        Margin is double-buffered, see :func:`WlSurface.commit()
        <pywayland.protocol.wayland.WlSurface.commit>`.

        :param top:
        :type top:
            `ArgumentType.Int`
        :param right:
        :type right:
            `ArgumentType.Int`
        :param bottom:
        :type bottom:
            `ArgumentType.Int`
        :param left:
        :type left:
            `ArgumentType.Int`
        """
        self._marshal(3, top, right, bottom, left)

    @ZwlrLayerSurfaceV1.request(
        Argument(ArgumentType.Uint),
    )
    def set_keyboard_interactivity(self, keyboard_interactivity: int) -> None:
        """Requests keyboard events

        Set how keyboard events are delivered to this surface. By default,
        layer shell surfaces do not receive keyboard events; this request can
        be used to change this.

        This setting is inherited by child surfaces set by the get_popup
        request.

        Layer surfaces receive pointer, touch, and tablet events normally. If
        you do not want to receive them, set the input region on your surface
        to an empty region.

        Keyboard interactivity is double-buffered, see
        :func:`WlSurface.commit()
        <pywayland.protocol.wayland.WlSurface.commit>`.

        :param keyboard_interactivity:
        :type keyboard_interactivity:
            `ArgumentType.Uint`
        """
        self._marshal(4, keyboard_interactivity)

    @ZwlrLayerSurfaceV1.request(
        Argument(ArgumentType.Object, interface=XdgPopup),
    )
    def get_popup(self, popup: XdgPopup) -> None:
        """Assign this layer_surface as an :class:`~pywayland.protocol.xdg_shell.XdgPopup` parent

        This assigns an xdg_popup's parent to this layer_surface.  This popup
        should have been created via
        :class:`~pywayland.protocol.xdg_shell.XdgSurface`::get_popup with the
        parent set to NULL, and this request must be invoked before committing
        the popup's initial state.

        See the documentation of
        :class:`~pywayland.protocol.xdg_shell.XdgPopup` for more details about
        what an :class:`~pywayland.protocol.xdg_shell.XdgPopup` is and how it
        is used.

        :param popup:
        :type popup:
            :class:`~pywayland.protocol.xdg_shell.XdgPopup`
        """
        self._marshal(5, popup)

    @ZwlrLayerSurfaceV1.request(
        Argument(ArgumentType.Uint),
    )
    def ack_configure(self, serial: int) -> None:
        """Ack a configure event

        When a configure event is received, if a client commits the surface in
        response to the configure event, then the client must make an
        ack_configure request sometime before the commit request, passing along
        the serial of the configure event.

        If the client receives multiple configure events before it can respond
        to one, it only has to ack the last configure event.

        A client is not required to commit immediately after sending an
        ack_configure request - it may even ack_configure several times before
        its next surface commit.

        A client may send multiple ack_configure requests before committing,
        but only the last request sent before a commit indicates which
        configure event the client really is responding to.

        :param serial:
            the serial from the configure event
        :type serial:
            `ArgumentType.Uint`
        """
        self._marshal(6, serial)

    @ZwlrLayerSurfaceV1.request()
    def destroy(self) -> None:
        """Destroy the layer_surface

        This request destroys the layer surface.
        """
        self._marshal(7)
        self._destroy()

    @ZwlrLayerSurfaceV1.request(
        Argument(ArgumentType.Uint),
        version=2,
    )
    def set_layer(self, layer: int) -> None:
        """Change the layer of the surface

        Change the layer that the surface is rendered on.

        Layer is double-buffered, see :func:`WlSurface.commit()
        <pywayland.protocol.wayland.WlSurface.commit>`.

        :param layer:
            layer to move this surface to
        :type layer:
            `ArgumentType.Uint`
        """
        self._marshal(8, layer)

    @ZwlrLayerSurfaceV1.request(
        Argument(ArgumentType.Uint),
        version=5,
    )
    def set_exclusive_edge(self, edge: int) -> None:
        """Set the edge the exclusive zone will be applied to

        Requests an edge for the exclusive zone to apply. The exclusive edge
        will be automatically deduced from anchor points when possible, but
        when the surface is anchored to a corner, it will be necessary to set
        it explicitly to disambiguate, as it is not possible to deduce which
        one of the two corner edges should be used.

        The edge must be one the surface is anchored to, otherwise the
        invalid_exclusive_edge protocol error will be raised.

        :param edge:
        :type edge:
            `ArgumentType.Uint`
        """
        self._marshal(9, edge)


class ZwlrLayerSurfaceV1Resource(Resource):
    interface = ZwlrLayerSurfaceV1

    @ZwlrLayerSurfaceV1.event(
        Argument(ArgumentType.Uint),
        Argument(ArgumentType.Uint),
        Argument(ArgumentType.Uint),
    )
    def configure(self, serial: int, width: int, height: int) -> None:
        """Suggest a surface change

        The configure event asks the client to resize its surface.

        Clients should arrange their surface for the new states, and then send
        an ack_configure request with the serial sent in this configure event
        at some point before committing the new surface.

        The client is free to dismiss all but the last configure event it
        received.

        The width and height arguments specify the size of the window in
        surface-local coordinates.

        The size is a hint, in the sense that the client is free to ignore it
        if it doesn't resize, pick a smaller size (to satisfy aspect ratio or
        resize in steps of NxM pixels). If the client picks a smaller size and
        is anchored to two opposite anchors (e.g. 'top' and 'bottom'), the
        surface will be centered on this axis.

        If the width or height arguments are zero, it means the client should
        decide its own window dimension.

        :param serial:
        :type serial:
            `ArgumentType.Uint`
        :param width:
        :type width:
            `ArgumentType.Uint`
        :param height:
        :type height:
            `ArgumentType.Uint`
        """
        self._post_event(0, serial, width, height)

    @ZwlrLayerSurfaceV1.event()
    def closed(self) -> None:
        """Surface should be closed

        The closed event is sent by the compositor when the surface will no
        longer be shown. The output may have been destroyed or the user may
        have asked for it to be removed. Further changes to the surface will be
        ignored. The client should destroy the resource after receiving this
        event, and create a new surface if they so choose.
        """
        self._post_event(1)


class ZwlrLayerSurfaceV1Global(Global):
    interface = ZwlrLayerSurfaceV1


ZwlrLayerSurfaceV1._gen_c()
ZwlrLayerSurfaceV1.proxy_class = ZwlrLayerSurfaceV1Proxy
ZwlrLayerSurfaceV1.resource_class = ZwlrLayerSurfaceV1Resource
ZwlrLayerSurfaceV1.global_class = ZwlrLayerSurfaceV1Global
